@@ -307,8 +307,8 @@ void file_info(const string name, int64_t value)
 {
     if(a) a->add_value(name,value); 
     if(t || x){
-	if(t) fprintf(t,"%s: %"PRId64"\n",cstr(name),value);
-	if(x) x->xmlprintf(name,"","%"PRId64,value);
+	if(t) fprintf(t,"%s: %" PRId64 "\n",cstr(name),value);
+	if(x) x->xmlprintf(name,"","%" PRId64,value);
     }
 }
 
@@ -401,10 +401,10 @@ bool has_unprintable(const u_char *buf,int buflen)
     return false;
 }
 
-void sig_info(int arg)
+void sig_info(int /*arg*/)
 {
     if(a){
-	printf("a=%p\n",a);
+	printf("a=%p\n", (void*)a);
 	printf("\n");
     }
 }
